import eslint from 'vite-plugin-eslint'
import packageJSON from './package.json'

// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  app: {
    head: {
      htmlAttrs: {
        lang: 'en',
      },
      link: [
        {
          rel: 'icon',
          type: 'image/x-icon',
          href: '/favicon.ico',
        },
      ],
      meta: [
        {
          charset: 'utf-8',
        },
        {
          name: 'viewport',
          content: 'width=device-width, initial-scale=1',
        },
        {
          'http-equiv': 'X-UA-Compatible',
          content: 'ie=edge',
        },
      ],
    },
    pageTransition: { name: 'page', mode: 'out-in' },
    rootId: 'ender-app',
  },
  components: {
    dirs: [
      {
        path: '~/components',
        pathPrefix: false,
        extensions: ['.vue'],
      },
    ],
  },
  css: [
    '~/assets/styles/main.min.css',
    '@fortawesome/fontawesome-svg-core/styles.css',
  ],
  plugins: [],
  modules: [
    'nuxt-font-loader',
    '@nuxt/content',
    [
      '@nuxtjs/eslint-module',
      { fix: true, failOnError: true, lintOnStart: false },
    ],
    '@pinia/nuxt',
    'nuxt-quasar-ui',
    ['@nuxtjs/stylelint-module', { failOnError: true, lintOnStart: false }],
  ],
  quasar: {
    lang: 'en-US',
  },
  typescript: {
    typeCheck: true,
  },
  runtimeConfig: {
    public: {
      version: JSON.stringify(packageJSON.version).slice(1, -1),
      buildDate: new Date().toISOString().split('T')[0],
    },
  },
})
